Crate snarkvm_ledger_narwhal_debug

Crate snarkvm_ledger_narwhal_debug 

Re-exports

pub use narwhal_batch_certificate as batch_certificate;
pub use narwhal_batch_header as batch_header;
pub use narwhal_data as data;
pub use narwhal_subdag as subdag;
pub use narwhal_transmission as transmission;
pub use narwhal_transmission_id as transmission_id;

Structs

BatchHeader
Subdag

Enums

BatchCertificate
Data
This object enables deferred deserialization / ahead-of-time serialization for objects that take a while to deserialize / serialize, in order to allow these operations to be non-blocking.
Transmission
TransmissionID